/*
 * Copyright (C) 2016 Google Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.google.android.apps.santatracker.dasherdancer;

import android.graphics.Point;
import android.support.annotation.DrawableRes;

import java.util.HashMap;

/**
 * To reduce RAM usage transparent areas were removed from all image frames for this game. This
 * class encodes the offsets needed to display all the frames so that they align with the
 * transparent regions removed.
 */
public class ResourceOffsets {

    private static HashMap<Integer, Point> offsets = new HashMap<>();
    private static Point EMPTY = new Point(0,0);

    public static Point ORIG_SIZE = new Point(1280, 1280);

    public static Point getOffsets(@DrawableRes int drawableId) {
        Point p = offsets.get(drawableId);
        return p == null ? EMPTY : p;
    }

    static {
        offsets.put(R.drawable.elf_pinchout0006, new Point(0, 0));
        offsets.put(R.drawable.snowman_swiperight0015, new Point(429, 221));
        offsets.put(R.drawable.reindeer_swipedown0018, new Point(365, 709));
        offsets.put(R.drawable.elf_shake0006, new Point(318, 230));
        offsets.put(R.drawable.reindeer_swipeleft0002, new Point(341, 331));
        offsets.put(R.drawable.reindeer_pinchout0024, new Point(342, 337));
        offsets.put(R.drawable.snowman_swipeup0023, new Point(429, 220));
        offsets.put(R.drawable.snowman_pinchout0001, new Point(429, 221));
        offsets.put(R.drawable.snowman_pinchout0022, new Point(334, 310));
        offsets.put(R.drawable.reindeer_swipedown0008, new Point(365, 705));
        offsets.put(R.drawable.santa_pinchin0007, new Point(136, 218));
        offsets.put(R.drawable.snowman_swipedown0021, new Point(429, 250));
        offsets.put(R.drawable.santa_idle0021, new Point(415, 434));
        offsets.put(R.drawable.santa_idle0024, new Point(415, 435));
        offsets.put(R.drawable.santa_pinchout20001, new Point(0, 0));
        offsets.put(R.drawable.reindeer_swipedown0009, new Point(376, 709));
        offsets.put(R.drawable.elf_swipedown0014, new Point(396, 611));
        offsets.put(R.drawable.snowman_pinchin0001, new Point(429, 221));
        offsets.put(R.drawable.snowman_pinchout0005, new Point(360, 434));
        offsets.put(R.drawable.santa_swipeleft0017, new Point(147, 628));
        offsets.put(R.drawable.reindeer_swipeup0013, new Point(210, 37));
        offsets.put(R.drawable.snowman_pinchin0012, new Point(90, 806));
        offsets.put(R.drawable.santa_swipeleft0009, new Point(94, 606));
        offsets.put(R.drawable.elf_pinchout0017, new Point(0, 0));
        offsets.put(R.drawable.snowman_swipeleft0007, new Point(429, 221));
        offsets.put(R.drawable.santa_idle0027, new Point(415, 432));
        offsets.put(R.drawable.snowman_tap0017, new Point(94, 221));
        offsets.put(R.drawable.santa_temp_tap01, new Point(415, 435));
        offsets.put(R.drawable.elf_swipeleft0023, new Point(435, 358));
        offsets.put(R.drawable.reindeer_swipeleft0019, new Point(384, 347));
        offsets.put(R.drawable.snowman_pinchin0009, new Point(90, 422));
        offsets.put(R.drawable.elf_idle0007, new Point(435, 437));
        offsets.put(R.drawable.snowman_idle0002, new Point(429, 220));
        offsets.put(R.drawable.reindeer_tap0008, new Point(342, 337));
        offsets.put(R.drawable.santa_swipe_right20005, new Point(350, 423));
        offsets.put(R.drawable.snowman_pinchout0003, new Point(395, 339));
        offsets.put(R.drawable.reindeer_pinchout0018, new Point(98, 37));
        offsets.put(R.drawable.snowman_swipeleft0004, new Point(429, 221));
        offsets.put(R.drawable.santa_idle0007, new Point(416, 430));
        offsets.put(R.drawable.snowman_swipeup0022, new Point(429, 219));
        offsets.put(R.drawable.santa_shake0005, new Point(229, 475));
        offsets.put(R.drawable.santa_swipeup0016, new Point(253, 221));
        offsets.put(R.drawable.snowman_tap0019, new Point(102, 221));
        offsets.put(R.drawable.santa_swipeup0023, new Point(427, 427));
        offsets.put(R.drawable.reindeer_pinchin0023, new Point(0, 0));
        offsets.put(R.drawable.snowman_swiperight0005, new Point(314, 221));
        offsets.put(R.drawable.elf_shake0016, new Point(285, 309));
        offsets.put(R.drawable.reindeer_swipeup0016, new Point(240, 73));
        offsets.put(R.drawable.reindeer_swipedown0023, new Point(344, 351));
        offsets.put(R.drawable.snowman_swiperight0024, new Point(429, 221));
        offsets.put(R.drawable.reindeer_swipeup0010, new Point(210, 34));
        offsets.put(R.drawable.reindeer_swipedown0007, new Point(375, 595));
        offsets.put(R.drawable.reindeer_pinchin0003, new Point(0, 0));
        offsets.put(R.drawable.santa_shake0010, new Point(241, 468));
        offsets.put(R.drawable.snowman_swipeleft0011, new Point(429, 221));
        offsets.put(R.drawable.elf_tap0018, new Point(435, 440));
        offsets.put(R.drawable.santa_swipeup0001, new Point(415, 435));
        offsets.put(R.drawable.elf_idle0012, new Point(435, 436));
        offsets.put(R.drawable.snowman_swiperight0008, new Point(271, 221));
        offsets.put(R.drawable.elf_idle0002, new Point(435, 440));
        offsets.put(R.drawable.snowman_pinchin0010, new Point(90, 513));
        offsets.put(R.drawable.elf_swiperight0011, new Point(1073, 707));
        offsets.put(R.drawable.santa_shake0003, new Point(279, 476));
        offsets.put(R.drawable.elf_swipeleft0012, new Point(294, 460));
        offsets.put(R.drawable.elf_tap0017, new Point(429, 436));
        offsets.put(R.drawable.elf_pinchin_ball0008, new Point(520, 914));
        offsets.put(R.drawable.snowman_swipeup0003, new Point(429, 182));
        offsets.put(R.drawable.santa_swipeleft0013, new Point(429, 608));
        offsets.put(R.drawable.snowman_pinchout0020, new Point(237, 580));
        offsets.put(R.drawable.reindeer_shake0018, new Point(384, 13));
        offsets.put(R.drawable.snowman_swipeleft0001, new Point(429, 221));
        offsets.put(R.drawable.reindeer_swipedown0005, new Point(381, 451));
        offsets.put(R.drawable.reindeer_shake0021, new Point(384, 206));
        offsets.put(R.drawable.snowman_idle0020, new Point(429, 218));
        offsets.put(R.drawable.reindeer_tap0022, new Point(342, 337));
        offsets.put(R.drawable.snowman_swipedown0020, new Point(429, 279));
        offsets.put(R.drawable.snowman_shake0005, new Point(115, 0));
        offsets.put(R.drawable.snowman_swipeup0012, new Point(429, 21));
        offsets.put(R.drawable.reindeer_tap0013, new Point(342, 337));
        offsets.put(R.drawable.reindeer_pinchin0008, new Point(0, 0));
        offsets.put(R.drawable.santa_shake0013, new Point(363, 426));
        offsets.put(R.drawable.elf_pinchin_ball0001, new Point(435, 440));
        offsets.put(R.drawable.snowman_idle0022, new Point(429, 219));
        offsets.put(R.drawable.reindeer_swipeleft0021, new Point(370, 339));
        offsets.put(R.drawable.santa_pinchin0017, new Point(270, 435));
        offsets.put(R.drawable.santa_idle0014, new Point(416, 430));
        offsets.put(R.drawable.elf_swiperight0020, new Point(252, 504));
        offsets.put(R.drawable.reindeer_tap0024, new Point(342, 337));
        offsets.put(R.drawable.elf_pinchout0015, new Point(0, 0));
        offsets.put(R.drawable.elf_tap0005, new Point(347, 380));
        offsets.put(R.drawable.snowman_pinchin0008, new Point(90, 367));
        offsets.put(R.drawable.snowman_idle0011, new Point(429, 217));
        offsets.put(R.drawable.reindeer_pinchin0018, new Point(0, 0));
        offsets.put(R.drawable.santa_idle0035, new Point(416, 429));
        offsets.put(R.drawable.reindeer_swipeup0015, new Point(218, 46));
        offsets.put(R.drawable.santa_idle0032, new Point(416, 429));
        offsets.put(R.drawable.elf_pinchout0020, new Point(106, 0));
        offsets.put(R.drawable.snowman_swipeup0007, new Point(427, 21));
        offsets.put(R.drawable.snowman_swipedown0013, new Point(429, 442));
        offsets.put(R.drawable.elf_swipedown0002, new Point(435, 440));
        offsets.put(R.drawable.snowman_swipedown0018, new Point(429, 212));
        offsets.put(R.drawable.santa_pinchin0009, new Point(96, 154));
        offsets.put(R.drawable.snowman_pinchin0005, new Point(55, 0));
        offsets.put(R.drawable.santa_idle0017, new Point(415, 432));
        offsets.put(R.drawable.santa_swipeleft0007, new Point(165, 589));
        offsets.put(R.drawable.santa_pinchout20015, new Point(0, 0));
        offsets.put(R.drawable.snowman_idle0014, new Point(429, 217));
        offsets.put(R.drawable.santa_idle0011, new Point(416, 429));
        offsets.put(R.drawable.reindeer_swipeleft0010, new Point(282, 280));
        offsets.put(R.drawable.reindeer_shake0013, new Point(383, 20));
        offsets.put(R.drawable.elf_shake0023, new Point(435, 471));
        offsets.put(R.drawable.snowman_swipeup0008, new Point(429, 21));
        offsets.put(R.drawable.santa_swipedown0007, new Point(429, 635));
        offsets.put(R.drawable.reindeer_swipeleft0003, new Point(338, 311));
        offsets.put(R.drawable.reindeer_pinchin0014, new Point(0, 0));
        offsets.put(R.drawable.santa_pinchout20004, new Point(0, 0));
        offsets.put(R.drawable.elf_swipeup0011, new Point(378, 6));
        offsets.put(R.drawable.reindeer_tap0003, new Point(350, 341));
        offsets.put(R.drawable.santa_swipeleft0004, new Point(314, 530));
        offsets.put(R.drawable.elf_idle0001, new Point(435, 440));
        offsets.put(R.drawable.elf_idle0006, new Point(435, 437));
        offsets.put(R.drawable.elf_shake0002, new Point(319, 369));
        offsets.put(R.drawable.elf_tap0010, new Point(100, 262));
        offsets.put(R.drawable.reindeer_tap0020, new Point(342, 337));
        offsets.put(R.drawable.santa_tap0008, new Point(270, 596));
        offsets.put(R.drawable.elf_idle0014, new Point(435, 436));
        offsets.put(R.drawable.santa_pinchin0015, new Point(215, 347));
        offsets.put(R.drawable.reindeer_swipedown0013, new Point(360, 709));
        offsets.put(R.drawable.reindeer_swipeup0020, new Point(334, 368));
        offsets.put(R.drawable.snowman_swiperight0009, new Point(139, 221));
        offsets.put(R.drawable.elf_pinchin_ball0016, new Point(515, 127));
        offsets.put(R.drawable.reindeer_swiperight0012, new Point(0, 1069));
        offsets.put(R.drawable.santa_pinchout20010, new Point(0, 0));
        offsets.put(R.drawable.snowman_swipedown0024, new Point(400, 266));
        offsets.put(R.drawable.reindeer_swipedown0017, new Point(363, 709));
        offsets.put(R.drawable.reindeer_swipeup0007, new Point(327, 105));
        offsets.put(R.drawable.elf_swipedown0005, new Point(435, 454));
        offsets.put(R.drawable.reindeer_swiperight0008, new Point(205, 660));
        offsets.put(R.drawable.reindeer_pinchin0015, new Point(0, 0));
        offsets.put(R.drawable.snowman_swipedown0001, new Point(429, 221));
        offsets.put(R.drawable.reindeer_shake0016, new Point(383, 17));
        offsets.put(R.drawable.reindeer_shake0008, new Point(384, 23));
        offsets.put(R.drawable.elf_swipeleft0024, new Point(435, 363));
        offsets.put(R.drawable.snowman_pinchout0019, new Point(237, 580));
        offsets.put(R.drawable.santa_shake0015, new Point(332, 421));
        offsets.put(R.drawable.reindeer_swiperight0016, new Point(211, 335));
        offsets.put(R.drawable.santa_shake0014, new Point(367, 422));
        offsets.put(R.drawable.elf_swipeup0003, new Point(386, 360));
        offsets.put(R.drawable.elf_tap0011, new Point(81, 270));
        offsets.put(R.drawable.santa_temp_left01, new Point(415, 435));
        offsets.put(R.drawable.elf_swipedown0018, new Point(435, 469));
        offsets.put(R.drawable.santa_idle0031, new Point(416, 430));
        offsets.put(R.drawable.elf_swipeup0006, new Point(476, 165));
        offsets.put(R.drawable.elf_swiperight0022, new Point(435, 459));
        offsets.put(R.drawable.snowman_swipeleft0003, new Point(429, 221));
        offsets.put(R.drawable.elf_swipeup0005, new Point(475, 262));
        offsets.put(R.drawable.snowman_pinchout0006, new Point(342, 473));
        offsets.put(R.drawable.elf_swipeleft0022, new Point(435, 352));
        offsets.put(R.drawable.elf_idle0021, new Point(435, 438));
        offsets.put(R.drawable.santa_swipeup0003, new Point(423, 402));
        offsets.put(R.drawable.snowman_shake0001, new Point(393, 221));
        offsets.put(R.drawable.reindeer_swipeleft0007, new Point(301, 225));
        offsets.put(R.drawable.snowman_swipeleft0024, new Point(429, 221));
        offsets.put(R.drawable.snowman_tap0013, new Point(79, 221));
        offsets.put(R.drawable.santa_idle0029, new Point(415, 431));
        offsets.put(R.drawable.santa_idle0041, new Point(415, 433));
        offsets.put(R.drawable.snowman_swiperight0006, new Point(139, 221));
        offsets.put(R.drawable.reindeer_swipedown0010, new Point(383, 709));
        offsets.put(R.drawable.santa_shake0023, new Point(351, 426));
        offsets.put(R.drawable.santa_swipedown0021, new Point(0, 159));
        offsets.put(R.drawable.snowman_idle0018, new Point(429, 218));
        offsets.put(R.drawable.reindeer_swipeleft0013, new Point(301, 324));
        offsets.put(R.drawable.reindeer_pinchout0004, new Point(331, 324));
        offsets.put(R.drawable.elf_pinchin_ball0014, new Point(520, 134));
        offsets.put(R.drawable.snowman_pinchin0006, new Point(35, 64));
        offsets.put(R.drawable.santa_swipedown0023, new Point(0, 435));
        offsets.put(R.drawable.santa_shake0021, new Point(344, 421));
        offsets.put(R.drawable.santa_swipe_right20020, new Point(401, 435));
        offsets.put(R.drawable.snowman_shake0010, new Point(100, 0));
        offsets.put(R.drawable.elf_swipedown0012, new Point(396, 611));
        offsets.put(R.drawable.elf_swipedown0009, new Point(400, 535));
        offsets.put(R.drawable.reindeer_pinchout0015, new Point(84, 20));
        offsets.put(R.drawable.reindeer_shake0014, new Point(384, 30));
        offsets.put(R.drawable.elf_swipeleft0013, new Point(269, 460));
        offsets.put(R.drawable.reindeer_shake0002, new Point(357, 301));
        offsets.put(R.drawable.reindeer_shake0001, new Point(342, 337));
        offsets.put(R.drawable.snowman_swipeup0013, new Point(415, 21));
        offsets.put(R.drawable.santa_shake0022, new Point(279, 422));
        offsets.put(R.drawable.santa_shake0017, new Point(377, 420));
        offsets.put(R.drawable.santa_pinchin0005, new Point(215, 347));
        offsets.put(R.drawable.snowman_swipeleft0005, new Point(429, 221));
        offsets.put(R.drawable.elf_swipeup0012, new Point(378, 119));
        offsets.put(R.drawable.santa_tap0011, new Point(270, 443));
        offsets.put(R.drawable.snowman_idle0009, new Point(429, 217));
        offsets.put(R.drawable.santa_tap0012, new Point(269, 443));
        offsets.put(R.drawable.snowman_swipeleft0006, new Point(429, 221));
        offsets.put(R.drawable.snowman_shake0002, new Point(130, 0));
        offsets.put(R.drawable.reindeer_swiperight0018, new Point(363, 338));
        offsets.put(R.drawable.elf_pinchout0014, new Point(0, 0));
        offsets.put(R.drawable.santa_shake0019, new Point(341, 420));
        offsets.put(R.drawable.elf_shake0021, new Point(228, 236));
        offsets.put(R.drawable.snowman_idle0017, new Point(429, 217));
        offsets.put(R.drawable.snowman_swiperight0007, new Point(191, 221));
        offsets.put(R.drawable.santa_swipedown0018, new Point(0, 0));
        offsets.put(R.drawable.snowman_tap0022, new Point(118, 221));
        offsets.put(R.drawable.snowman_swiperight0003, new Point(224, 221));
        offsets.put(R.drawable.elf_swipedown0003, new Point(435, 414));
        offsets.put(R.drawable.snowman_swipeup0005, new Point(429, 70));
        offsets.put(R.drawable.elf_pinchout0012, new Point(0, 0));
        offsets.put(R.drawable.snowman_swipedown0006, new Point(253, 447));
        offsets.put(R.drawable.snowman_pinchin0004, new Point(22, 0));
        offsets.put(R.drawable.snowman_swiperight0001, new Point(429, 221));
        offsets.put(R.drawable.santa_swipedown0010, new Point(429, 635));
        offsets.put(R.drawable.snowman_idle0013, new Point(429, 217));
        offsets.put(R.drawable.reindeer_swiperight0003, new Point(344, 337));
        offsets.put(R.drawable.elf_tap0008, new Point(175, 254));
        offsets.put(R.drawable.snowman_swipeup0011, new Point(429, 21));
        offsets.put(R.drawable.santa_swipedown0006, new Point(429, 635));
        offsets.put(R.drawable.reindeer_pinchin0011, new Point(0, 0));
        offsets.put(R.drawable.santa_idle0036, new Point(416, 429));
        offsets.put(R.drawable.snowman_swiperight0017, new Point(429, 221));
        offsets.put(R.drawable.snowman_swipedown0012, new Point(425, 350));
        offsets.put(R.drawable.santa_swipedown0005, new Point(429, 610));
        offsets.put(R.drawable.elf_tap0020, new Point(435, 440));
        offsets.put(R.drawable.santa_idle0016, new Point(415, 432));
        offsets.put(R.drawable.snowman_shake0017, new Point(72, 0));
        offsets.put(R.drawable.elf_pinchin_ball0024, new Point(520, 518));
        offsets.put(R.drawable.snowman_swipedown0007, new Point(226, 419));
        offsets.put(R.drawable.reindeer_pinchout0021, new Point(183, 142));
        offsets.put(R.drawable.reindeer_pinchin0022, new Point(0, 0));
        offsets.put(R.drawable.santa_swipedown0008, new Point(429, 635));
        offsets.put(R.drawable.elf_tap0015, new Point(382, 398));
        offsets.put(R.drawable.reindeer_pinchout0003, new Point(339, 334));
        offsets.put(R.drawable.reindeer_swipeleft0022, new Point(353, 338));
        offsets.put(R.drawable.elf_shake0011, new Point(343, 183));
        offsets.put(R.drawable.elf_swiperight0002, new Point(423, 441));
        offsets.put(R.drawable.reindeer_swipeup0006, new Point(353, 154));
        offsets.put(R.drawable.elf_tap0016, new Point(412, 422));
        offsets.put(R.drawable.santa_temp_shake01, new Point(415, 435));
        offsets.put(R.drawable.elf_swipeup0021, new Point(435, 480));
        offsets.put(R.drawable.elf_idle0009, new Point(435, 437));
        offsets.put(R.drawable.elf_swipedown0016, new Point(433, 561));
        offsets.put(R.drawable.santa_pinchout20006, new Point(0, 0));
        offsets.put(R.drawable.santa_pinchout20020, new Point(0, 0));
        offsets.put(R.drawable.reindeer_pinchout0007, new Point(276, 255));
        offsets.put(R.drawable.santa_idle0048, new Point(415, 435));
        offsets.put(R.drawable.snowman_idle0003, new Point(429, 219));
        offsets.put(R.drawable.elf_swipeleft0019, new Point(432, 393));
        offsets.put(R.drawable.santa_pinchout20012, new Point(0, 0));
        offsets.put(R.drawable.reindeer_pinchout0016, new Point(82, 17));
        offsets.put(R.drawable.elf_tap0024, new Point(435, 440));
        offsets.put(R.drawable.santa_idle0040, new Point(415, 432));
        offsets.put(R.drawable.elf_swiperight0017, new Point(0, 606));
        offsets.put(R.drawable.snowman_swiperight0011, new Point(330, 221));
        offsets.put(R.drawable.santa_idle0001, new Point(415, 435));
        offsets.put(R.drawable.snowman_tap0004, new Point(245, 227));
        offsets.put(R.drawable.elf_tap0013, new Point(286, 324));
        offsets.put(R.drawable.elf_shake0012, new Point(318, 233));
        offsets.put(R.drawable.elf_pinchout0008, new Point(0, 0));
        offsets.put(R.drawable.santa_pinchin0016, new Point(270, 435));
        offsets.put(R.drawable.snowman_swipedown0016, new Point(422, 13));
        offsets.put(R.drawable.reindeer_pinchin0004, new Point(0, 0));
        offsets.put(R.drawable.santa_swipeup0005, new Point(429, 375));
        offsets.put(R.drawable.snowman_shake0003, new Point(126, 21));
        offsets.put(R.drawable.elf_pinchout0004, new Point(0, 0));
        offsets.put(R.drawable.reindeer_swipedown0004, new Point(364, 401));
        offsets.put(R.drawable.reindeer_pinchout0023, new Point(281, 262));
        offsets.put(R.drawable.santa_swipeleft0018, new Point(216, 579));
        offsets.put(R.drawable.elf_pinchout0018, new Point(0, 0));
        offsets.put(R.drawable.reindeer_shake0004, new Point(383, 13));
        offsets.put(R.drawable.reindeer_pinchin0016, new Point(0, 0));
        offsets.put(R.drawable.santa_swipe_right20001, new Point(415, 435));
        offsets.put(R.drawable.santa_swipe_right20021, new Point(389, 435));
        offsets.put(R.drawable.santa_swipeleft0014, new Point(429, 508));
        offsets.put(R.drawable.elf_shake0018, new Point(279, 233));
        offsets.put(R.drawable.santa_idle0003, new Point(415, 433));
        offsets.put(R.drawable.santa_swipeup0018, new Point(317, 317));
        offsets.put(R.drawable.elf_idle0010, new Point(435, 436));
        offsets.put(R.drawable.snowman_pinchin0024, new Point(401, 220));
        offsets.put(R.drawable.snowman_swiperight0016, new Point(429, 221));
        offsets.put(R.drawable.snowman_pinchin0007, new Point(35, 64));
        offsets.put(R.drawable.snowman_swipeup0010, new Point(429, 21));
        offsets.put(R.drawable.reindeer_pinchin0020, new Point(0, 0));
        offsets.put(R.drawable.elf_swipedown0015, new Point(400, 605));
        offsets.put(R.drawable.elf_tap0014, new Point(337, 366));
        offsets.put(R.drawable.elf_tap0006, new Point(290, 333));
        offsets.put(R.drawable.elf_swiperight0023, new Point(423, 440));
        offsets.put(R.drawable.santa_swipe_right20023, new Point(415, 435));
        offsets.put(R.drawable.snowman_swipeup0024, new Point(429, 221));
        offsets.put(R.drawable.snowman_tap0002, new Point(381, 227));
        offsets.put(R.drawable.santa_swipedown0022, new Point(0, 414));
        offsets.put(R.drawable.santa_swipe_right20017, new Point(415, 385));
        offsets.put(R.drawable.reindeer_swipedown0024, new Point(342, 337));
        offsets.put(R.drawable.elf_pinchin_ball0012, new Point(519, 270));
        offsets.put(R.drawable.reindeer_tap0014, new Point(342, 337));
        offsets.put(R.drawable.santa_idle0008, new Point(416, 430));
        offsets.put(R.drawable.snowman_idle0001, new Point(429, 221));
        offsets.put(R.drawable.reindeer_pinchout0010, new Point(177, 135));
        offsets.put(R.drawable.reindeer_swipeup0019, new Point(349, 266));
        offsets.put(R.drawable.santa_tap0022, new Point(358, 435));
        offsets.put(R.drawable.santa_swipeup0012, new Point(417, 213));
        offsets.put(R.drawable.snowman_idle0019, new Point(429, 218));
        offsets.put(R.drawable.elf_swipedown0023, new Point(435, 460));
        offsets.put(R.drawable.elf_pinchin_ball0025, new Point(476, 280));
        offsets.put(R.drawable.santa_swipe_right20009, new Point(332, 416));
        offsets.put(R.drawable.santa_idle0038, new Point(415, 431));
        offsets.put(R.drawable.snowman_pinchout0021, new Point(285, 423));
        offsets.put(R.drawable.santa_swipeup0022, new Point(420, 438));
        offsets.put(R.drawable.elf_pinchin_ball0007, new Point(497, 828));
        offsets.put(R.drawable.reindeer_shake0023, new Point(342, 346));
        offsets.put(R.drawable.snowman_idle0023, new Point(429, 220));
        offsets.put(R.drawable.snowman_swiperight0012, new Point(399, 221));
        offsets.put(R.drawable.elf_shake0024, new Point(435, 440));
        offsets.put(R.drawable.reindeer_pinchout0017, new Point(86, 22));
        offsets.put(R.drawable.reindeer_swipedown0001, new Point(342, 337));
        offsets.put(R.drawable.snowman_pinchin0021, new Point(182, 191));
        offsets.put(R.drawable.snowman_swipeup0020, new Point(429, 221));
        offsets.put(R.drawable.reindeer_shake0019, new Point(384, 34));
        offsets.put(R.drawable.elf_swipeleft0009, new Point(391, 460));
        offsets.put(R.drawable.elf_pinchout0011, new Point(0, 0));
        offsets.put(R.drawable.snowman_tap0016, new Point(90, 221));
        offsets.put(R.drawable.elf_shake0004, new Point(228, 236));
        offsets.put(R.drawable.snowman_tap0020, new Point(105, 221));
        offsets.put(R.drawable.elf_pinchout0022, new Point(464, 489));
        offsets.put(R.drawable.santa_swipedown0011, new Point(345, 613));
        offsets.put(R.drawable.elf_pinchin_ball0029, new Point(404, 450));
        offsets.put(R.drawable.elf_shake0013, new Point(201, 285));
        offsets.put(R.drawable.santa_swipeup0007, new Point(429, 304));
        offsets.put(R.drawable.snowman_idle0016, new Point(429, 217));
        offsets.put(R.drawable.santa_swipe_right20010, new Point(312, 437));
        offsets.put(R.drawable.reindeer_swipeup0018, new Point(329, 183));
        offsets.put(R.drawable.reindeer_tap0010, new Point(342, 337));
        offsets.put(R.drawable.elf_swipedown0001, new Point(435, 440));
        offsets.put(R.drawable.reindeer_pinchin0024, new Point(0, 0));
        offsets.put(R.drawable.elf_swipeup0020, new Point(404, 450));
        offsets.put(R.drawable.elf_pinchout0023, new Point(459, 480));
        offsets.put(R.drawable.santa_pinchin0018, new Point(235, 505));
        offsets.put(R.drawable.reindeer_pinchin0019, new Point(0, 0));
        offsets.put(R.drawable.santa_shake0006, new Point(245, 474));
        offsets.put(R.drawable.snowman_shake0019, new Point(74, 0));
        offsets.put(R.drawable.santa_idle0019, new Point(415, 434));
        offsets.put(R.drawable.snowman_swipedown0011, new Point(394, 381));
        offsets.put(R.drawable.snowman_pinchin0020, new Point(167, 189));
        offsets.put(R.drawable.santa_idle0043, new Point(415, 434));
        offsets.put(R.drawable.snowman_swipeleft0013, new Point(415, 221));
        offsets.put(R.drawable.reindeer_swipeup0023, new Point(193, 338));
        offsets.put(R.drawable.santa_pinchout20011, new Point(0, 0));
        offsets.put(R.drawable.elf_swiperight0003, new Point(435, 425));
        offsets.put(R.drawable.reindeer_swipedown0014, new Point(343, 709));
        offsets.put(R.drawable.santa_swipeleft0020, new Point(351, 467));
        offsets.put(R.drawable.snowman_swipeleft0023, new Point(429, 221));
        offsets.put(R.drawable.reindeer_swipeup0021, new Point(268, 354));
        offsets.put(R.drawable.snowman_tap0009, new Point(79, 221));
        offsets.put(R.drawable.elf_shake0009, new Point(201, 285));
        offsets.put(R.drawable.santa_swipeleft0003, new Point(374, 516));
        offsets.put(R.drawable.snowman_swipeleft0022, new Point(429, 221));
        offsets.put(R.drawable.elf_pinchout0013, new Point(0, 0));
        offsets.put(R.drawable.santa_tap0015, new Point(270, 412));
        offsets.put(R.drawable.snowman_pinchout0002, new Point(412, 283));
        offsets.put(R.drawable.elf_swipedown0010, new Point(397, 556));
        offsets.put(R.drawable.elf_pinchin_ball0011, new Point(521, 426));
        offsets.put(R.drawable.reindeer_swipedown0012, new Point(378, 709));
        offsets.put(R.drawable.santa_pinchin0002, new Point(358, 435));
        offsets.put(R.drawable.reindeer_tap0004, new Point(346, 339));
        offsets.put(R.drawable.snowman_shake0015, new Point(83, 0));
        offsets.put(R.drawable.santa_shake0016, new Point(322, 420));
        offsets.put(R.drawable.snowman_pinchin0014, new Point(90, 1245));
        offsets.put(R.drawable.reindeer_swiperight0023, new Point(330, 341));
        offsets.put(R.drawable.santa_pinchin0019, new Point(224, 529));
        offsets.put(R.drawable.reindeer_swipeleft0018, new Point(384, 355));
        offsets.put(R.drawable.reindeer_shake0015, new Point(384, 23));
        offsets.put(R.drawable.snowman_pinchin0011, new Point(90, 641));
        offsets.put(R.drawable.santa_swipe_right20011, new Point(412, 394));
        offsets.put(R.drawable.santa_pinchin0004, new Point(270, 435));
        offsets.put(R.drawable.snowman_shake0021, new Point(68, 11));
        offsets.put(R.drawable.reindeer_swipeleft0012, new Point(291, 300));
        offsets.put(R.drawable.elf_idle0018, new Point(435, 437));
        offsets.put(R.drawable.santa_swipeup0006, new Point(429, 334));
        offsets.put(R.drawable.reindeer_pinchout0006, new Point(299, 285));
        offsets.put(R.drawable.santa_pinchin0001, new Point(415, 435));
        offsets.put(R.drawable.santa_swipeup0020, new Point(425, 462));
        offsets.put(R.drawable.elf_swipeleft0007, new Point(362, 460));
        offsets.put(R.drawable.snowman_tap0015, new Point(87, 221));
        offsets.put(R.drawable.elf_swiperight0007, new Point(506, 517));
        offsets.put(R.drawable.elf_swipeup0016, new Point(476, 200));
        offsets.put(R.drawable.elf_swipeleft0020, new Point(435, 389));
        offsets.put(R.drawable.santa_swipedown0009, new Point(429, 635));
        offsets.put(R.drawable.santa_swipe_right20002, new Point(420, 435));
        offsets.put(R.drawable.elf_swipeleft0015, new Point(369, 460));
        offsets.put(R.drawable.elf_swipeleft0002, new Point(414, 441));
        offsets.put(R.drawable.elf_swipeleft0008, new Point(393, 460));
        offsets.put(R.drawable.snowman_pinchout0018, new Point(237, 580));
        offsets.put(R.drawable.santa_tap0002, new Point(358, 435));
        offsets.put(R.drawable.santa_tap0019, new Point(270, 423));
        offsets.put(R.drawable.elf_pinchout0007, new Point(0, 0));
        offsets.put(R.drawable.snowman_swiperight0018, new Point(429, 221));
        offsets.put(R.drawable.snowman_pinchout0014, new Point(237, 580));
        offsets.put(R.drawable.elf_pinchin_ball0006, new Point(487, 762));
        offsets.put(R.drawable.snowman_pinchout0011, new Point(255, 577));
        offsets.put(R.drawable.snowman_swiperight0022, new Point(417, 221));
        offsets.put(R.drawable.reindeer_swiperight0021, new Point(325, 361));
        offsets.put(R.drawable.snowman_idle0007, new Point(429, 217));
        offsets.put(R.drawable.santa_swipedown0013, new Point(266, 0));
        offsets.put(R.drawable.santa_pinchout20002, new Point(0, 0));
        offsets.put(R.drawable.santa_swipeup0019, new Point(422, 428));
        offsets.put(R.drawable.snowman_swipeleft0016, new Point(429, 221));
        offsets.put(R.drawable.elf_swipeup0004, new Point(435, 200));
        offsets.put(R.drawable.santa_swipeleft0006, new Point(209, 565));
        offsets.put(R.drawable.santa_idle0005, new Point(415, 431));
        offsets.put(R.drawable.reindeer_swipeup0014, new Point(210, 37));
        offsets.put(R.drawable.elf_shake0010, new Point(285, 309));
        offsets.put(R.drawable.reindeer_swipeleft0008, new Point(290, 260));
        offsets.put(R.drawable.snowman_swipeup0016, new Point(219, 21));
        offsets.put(R.drawable.reindeer_swipeup0003, new Point(342, 275));
        offsets.put(R.drawable.reindeer_swiperight0009, new Point(121, 685));
        offsets.put(R.drawable.reindeer_swiperight0017, new Point(249, 332));
        offsets.put(R.drawable.elf_swipeup0015, new Point(476, 311));
        offsets.put(R.drawable.elf_swipeup0013, new Point(397, 259));
        offsets.put(R.drawable.santa_shake0024, new Point(355, 435));
        offsets.put(R.drawable.santa_shake0002, new Point(328, 456));
        offsets.put(R.drawable.reindeer_swipeleft0004, new Point(333, 279));
        offsets.put(R.drawable.snowman_shake0016, new Point(76, 0));
        offsets.put(R.drawable.santa_swipedown0014, new Point(262, 0));
        offsets.put(R.drawable.reindeer_swipedown0019, new Point(384, 601));
        offsets.put(R.drawable.elf_pinchin_ball0031, new Point(435, 458));
        offsets.put(R.drawable.santa_idle0046, new Point(415, 435));
        offsets.put(R.drawable.elf_tap0021, new Point(435, 440));
        offsets.put(R.drawable.elf_tap0019, new Point(435, 440));
        offsets.put(R.drawable.elf_pinchin_ball0020, new Point(520, 898));
        offsets.put(R.drawable.santa_tap0005, new Point(270, 509));
        offsets.put(R.drawable.santa_idle0009, new Point(416, 429));
        offsets.put(R.drawable.santa_temp_down01, new Point(415, 435));
        offsets.put(R.drawable.elf_pinchout0019, new Point(50, 0));
        offsets.put(R.drawable.snowman_tap0006, new Point(146, 221));
        offsets.put(R.drawable.elf_swiperight0021, new Point(427, 451));
        offsets.put(R.drawable.santa_swipeup0021, new Point(399, 471));
        offsets.put(R.drawable.elf_idle0019, new Point(435, 438));
        offsets.put(R.drawable.elf_swiperight0010, new Point(888, 568));
        offsets.put(R.drawable.elf_swipeup0001, new Point(435, 440));
        offsets.put(R.drawable.reindeer_swipedown0021, new Point(371, 437));
        offsets.put(R.drawable.snowman_swipeleft0019, new Point(429, 221));
        offsets.put(R.drawable.reindeer_shake0020, new Point(384, 99));
        offsets.put(R.drawable.snowman_tap0008, new Point(79, 221));
        offsets.put(R.drawable.santa_idle0020, new Point(415, 434));
        offsets.put(R.drawable.snowman_pinchout0015, new Point(237, 580));
        offsets.put(R.drawable.snowman_tap0024, new Point(429, 221));
        offsets.put(R.drawable.snowman_swipeup0004, new Point(429, 133));
        offsets.put(R.drawable.reindeer_swipeleft0001, new Point(342, 337));
        offsets.put(R.drawable.snowman_shake0007, new Point(108, 0));
        offsets.put(R.drawable.santa_swipeleft0015, new Point(415, 416));
        offsets.put(R.drawable.elf_tap0012, new Point(221, 272));
        offsets.put(R.drawable.elf_pinchout0003, new Point(250, 0));
        offsets.put(R.drawable.reindeer_shake0022, new Point(342, 357));
        offsets.put(R.drawable.reindeer_shake0005, new Point(384, 13));
        offsets.put(R.drawable.snowman_swipeleft0021, new Point(429, 221));
        offsets.put(R.drawable.reindeer_swipedown0006, new Point(384, 516));
        offsets.put(R.drawable.elf_swiperight0018, new Point(0, 538));
        offsets.put(R.drawable.elf_idle0008, new Point(435, 437));
        offsets.put(R.drawable.reindeer_swipeup0017, new Point(277, 119));
        offsets.put(R.drawable.elf_pinchin_ball0022, new Point(513, 738));
        offsets.put(R.drawable.elf_swipeup0018, new Point(454, 400));
        offsets.put(R.drawable.santa_swipeup0010, new Point(429, 266));
        offsets.put(R.drawable.snowman_pinchout0009, new Point(290, 553));
        offsets.put(R.drawable.elf_pinchin_ball0010, new Point(521, 653));
        offsets.put(R.drawable.snowman_tap0011, new Point(79, 221));
        offsets.put(R.drawable.santa_pinchout20014, new Point(0, 0));
        offsets.put(R.drawable.elf_swipeleft0006, new Point(330, 460));
        offsets.put(R.drawable.elf_swipeleft0004, new Point(372, 441));
        offsets.put(R.drawable.elf_tap0001, new Point(435, 440));
        offsets.put(R.drawable.snowman_swiperight0020, new Point(429, 221));
        offsets.put(R.drawable.reindeer_swiperight0015, new Point(0, 335));
        offsets.put(R.drawable.snowman_shake0008, new Point(110, 0));
        offsets.put(R.drawable.santa_idle0023, new Point(415, 435));
        offsets.put(R.drawable.elf_swipeup0009, new Point(357, 152));
        offsets.put(R.drawable.elf_swipeup0002, new Point(386, 400));
        offsets.put(R.drawable.snowman_swipedown0010, new Point(335, 435));
        offsets.put(R.drawable.santa_swipe_right20015, new Point(415, 353));
        offsets.put(R.drawable.reindeer_swipeleft0023, new Point(344, 337));
        offsets.put(R.drawable.santa_pinchout20003, new Point(0, 0));
        offsets.put(R.drawable.snowman_swiperight0013, new Point(429, 221));
        offsets.put(R.drawable.snowman_swipedown0015, new Point(429, 261));
        offsets.put(R.drawable.snowman_swipeup0014, new Point(346, 21));
        offsets.put(R.drawable.snowman_swipedown0008, new Point(207, 344));
        offsets.put(R.drawable.reindeer_pinchout0012, new Point(124, 69));
        offsets.put(R.drawable.santa_temp_zoom_in01, new Point(415, 435));
        offsets.put(R.drawable.reindeer_pinchin0021, new Point(0, 0));
        offsets.put(R.drawable.santa_tap0017, new Point(270, 423));
        offsets.put(R.drawable.snowman_shake0006, new Point(110, 0));
        offsets.put(R.drawable.reindeer_tap0006, new Point(342, 337));
        offsets.put(R.drawable.elf_idle0024, new Point(435, 440));
        offsets.put(R.drawable.santa_idle0034, new Point(416, 429));
        offsets.put(R.drawable.santa_swipeleft0005, new Point(258, 546));
        offsets.put(R.drawable.elf_pinchin_ball0027, new Point(459, 400));
        offsets.put(R.drawable.reindeer_tap0005, new Point(342, 337));
        offsets.put(R.drawable.elf_swipedown0020, new Point(435, 470));
        offsets.put(R.drawable.elf_idle0011, new Point(435, 436));
        offsets.put(R.drawable.snowman_swipeup0001, new Point(429, 221));
        offsets.put(R.drawable.santa_swipedown0001, new Point(415, 435));
        offsets.put(R.drawable.elf_shake0008, new Point(318, 362));
        offsets.put(R.drawable.reindeer_pinchout0022, new Point(228, 197));
        offsets.put(R.drawable.reindeer_pinchout0014, new Point(92, 30));
        offsets.put(R.drawable.snowman_swipedown0002, new Point(400, 266));
        offsets.put(R.drawable.reindeer_swiperight0001, new Point(342, 337));
        offsets.put(R.drawable.santa_swipedown0019, new Point(0, 0));
        offsets.put(R.drawable.santa_swipeleft0024, new Point(429, 424));
        offsets.put(R.drawable.reindeer_swiperight0005, new Point(354, 337));
        offsets.put(R.drawable.santa_pinchout20023, new Point(0, 0));
        offsets.put(R.drawable.snowman_swipeup0002, new Point(429, 211));
        offsets.put(R.drawable.santa_idle0022, new Point(415, 435));
        offsets.put(R.drawable.elf_swipeleft0010, new Point(317, 460));
        offsets.put(R.drawable.snowman_tap0007, new Point(95, 221));
        offsets.put(R.drawable.santa_swipedown0002, new Point(358, 435));
        offsets.put(R.drawable.snowman_pinchout0016, new Point(237, 580));
        offsets.put(R.drawable.santa_idle0018, new Point(415, 433));
        offsets.put(R.drawable.reindeer_shake0010, new Point(383, 13));
        offsets.put(R.drawable.santa_tap0014, new Point(270, 320));
        offsets.put(R.drawable.santa_shake0020, new Point(386, 420));
        offsets.put(R.drawable.snowman_swipeup0017, new Point(231, 33));
        offsets.put(R.drawable.elf_swipeup0023, new Point(435, 445));
        offsets.put(R.drawable.elf_tap0007, new Point(221, 272));
        offsets.put(R.drawable.snowman_idle0021, new Point(429, 219));
        offsets.put(R.drawable.elf_pinchin_ball0013, new Point(519, 169));
        offsets.put(R.drawable.santa_tap0021, new Point(270, 435));
        offsets.put(R.drawable.elf_pinchin_ball0018, new Point(506, 385));
        offsets.put(R.drawable.santa_pinchin0006, new Point(171, 275));
        offsets.put(R.drawable.reindeer_swipedown0015, new Point(349, 709));
        offsets.put(R.drawable.santa_swipe_right20007, new Point(341, 418));
        offsets.put(R.drawable.reindeer_swiperight0022, new Point(304, 370));
        offsets.put(R.drawable.santa_swipeleft0002, new Point(398, 476));
        offsets.put(R.drawable.santa_swipedown0004, new Point(340, 535));
        offsets.put(R.drawable.elf_idle0023, new Point(435, 440));
        offsets.put(R.drawable.santa_tap0020, new Point(270, 443));
        offsets.put(R.drawable.elf_tap0023, new Point(435, 440));
        offsets.put(R.drawable.reindeer_swipedown0016, new Point(357, 709));
        offsets.put(R.drawable.snowman_swipedown0005, new Point(285, 401));
        offsets.put(R.drawable.reindeer_tap0009, new Point(342, 337));
        offsets.put(R.drawable.snowman_swipeup0021, new Point(429, 220));
        offsets.put(R.drawable.elf_swipedown0006, new Point(435, 475));
        offsets.put(R.drawable.reindeer_swipeleft0011, new Point(284, 285));
        offsets.put(R.drawable.snowman_shake0014, new Point(87, 3));
        offsets.put(R.drawable.snowman_idle0006, new Point(429, 218));
        offsets.put(R.drawable.santa_swipe_right20004, new Point(350, 428));
        offsets.put(R.drawable.reindeer_swipeleft0005, new Point(326, 235));
        offsets.put(R.drawable.snowman_idle0004, new Point(429, 219));
        offsets.put(R.drawable.elf_shake0001, new Point(435, 440));
        offsets.put(R.drawable.santa_pinchout20013, new Point(0, 0));
        offsets.put(R.drawable.reindeer_tap0023, new Point(342, 337));
        offsets.put(R.drawable.elf_swipedown0022, new Point(435, 463));
        offsets.put(R.drawable.elf_swipeup0017, new Point(456, 380));
        offsets.put(R.drawable.snowman_pinchout0013, new Point(237, 580));
        offsets.put(R.drawable.santa_swipeleft0016, new Point(299, 540));
        offsets.put(R.drawable.snowman_pinchout0010, new Point(272, 568));
        offsets.put(R.drawable.snowman_tap0003, new Point(277, 248));
        offsets.put(R.drawable.santa_shake0001, new Point(355, 435));
        offsets.put(R.drawable.elf_swiperight0009, new Point(769, 641));
        offsets.put(R.drawable.santa_swipe_right20016, new Point(415, 370));
        offsets.put(R.drawable.elf_pinchout0016, new Point(0, 0));
        offsets.put(R.drawable.santa_idle0010, new Point(416, 429));
        offsets.put(R.drawable.elf_swiperight0006, new Point(441, 476));
        offsets.put(R.drawable.elf_swipeup0007, new Point(492, 165));
        offsets.put(R.drawable.elf_idle0017, new Point(435, 437));
        offsets.put(R.drawable.santa_swipeleft0008, new Point(127, 618));
        offsets.put(R.drawable.santa_pinchout20021, new Point(0, 0));
        offsets.put(R.drawable.reindeer_pinchin0013, new Point(0, 0));
        offsets.put(R.drawable.santa_idle0013, new Point(416, 429));
        offsets.put(R.drawable.snowman_swipedown0009, new Point(266, 281));
        offsets.put(R.drawable.santa_tap0023, new Point(415, 435));
        offsets.put(R.drawable.snowman_swipedown0014, new Point(429, 411));
        offsets.put(R.drawable.elf_tap0003, new Point(427, 434));
        offsets.put(R.drawable.snowman_pinchin0003, new Point(193, 109));
        offsets.put(R.drawable.santa_swipeleft0012, new Point(429, 558));
        offsets.put(R.drawable.snowman_idle0005, new Point(429, 218));
        offsets.put(R.drawable.snowman_idle0010, new Point(429, 217));
        offsets.put(R.drawable.santa_swipedown0016, new Point(429, 402));
        offsets.put(R.drawable.reindeer_swiperight0010, new Point(61, 1026));
        offsets.put(R.drawable.snowman_pinchout0012, new Point(237, 580));
        offsets.put(R.drawable.elf_idle0005, new Point(435, 438));
        offsets.put(R.drawable.reindeer_tap0002, new Point(346, 339));
        offsets.put(R.drawable.elf_tap0004, new Point(401, 413));
        offsets.put(R.drawable.santa_idle0030, new Point(416, 430));
        offsets.put(R.drawable.santa_swipeup0024, new Point(415, 435));
        offsets.put(R.drawable.elf_pinchin_ball0023, new Point(521, 583));
        offsets.put(R.drawable.reindeer_pinchin0001, new Point(0, 0));
        offsets.put(R.drawable.reindeer_pinchout0009, new Point(212, 177));
        offsets.put(R.drawable.reindeer_pinchout0001, new Point(342, 337));
        offsets.put(R.drawable.santa_swipeleft0022, new Point(398, 448));
        offsets.put(R.drawable.reindeer_swiperight0006, new Point(363, 644));
        offsets.put(R.drawable.snowman_tap0010, new Point(79, 221));
        offsets.put(R.drawable.elf_pinchout0024, new Point(444, 455));
        offsets.put(R.drawable.elf_pinchout0001, new Point(435, 440));
        offsets.put(R.drawable.snowman_swipedown0023, new Point(429, 221));
        offsets.put(R.drawable.santa_swipe_right20003, new Point(347, 435));
        offsets.put(R.drawable.snowman_swipeleft0020, new Point(429, 221));
        offsets.put(R.drawable.reindeer_shake0024, new Point(342, 339));
        offsets.put(R.drawable.snowman_pinchin0022, new Point(226, 197));
        offsets.put(R.drawable.snowman_shake0020, new Point(73, 5));
        offsets.put(R.drawable.santa_tap0013, new Point(270, 412));
        offsets.put(R.drawable.elf_swipeleft0003, new Point(393, 440));
        offsets.put(R.drawable.snowman_shake0024, new Point(382, 216));
        offsets.put(R.drawable.santa_tap0007, new Point(270, 586));
        offsets.put(R.drawable.snowman_shake0013, new Point(88, 0));
        offsets.put(R.drawable.snowman_tap0021, new Point(118, 221));
        offsets.put(R.drawable.elf_swipeup0010, new Point(378, 84));
        offsets.put(R.drawable.elf_swipedown0011, new Point(397, 560));
        offsets.put(R.drawable.snowman_pinchin0023, new Point(299, 207));
        offsets.put(R.drawable.elf_swiperight0019, new Point(83, 515));
        offsets.put(R.drawable.reindeer_swipeup0008, new Point(210, 47));
        offsets.put(R.drawable.snowman_tap0012, new Point(79, 221));
        offsets.put(R.drawable.reindeer_swipeleft0015, new Point(338, 400));
        offsets.put(R.drawable.reindeer_tap0011, new Point(342, 337));
        offsets.put(R.drawable.elf_swiperight0013, new Point(0, 730));
        offsets.put(R.drawable.santa_idle0028, new Point(415, 431));
        offsets.put(R.drawable.snowman_idle0024, new Point(429, 221));
        offsets.put(R.drawable.snowman_pinchin0015, new Point(1280/2, 1280/2));
        offsets.put(R.drawable.santa_pinchin0010, new Point(91, 146));
        offsets.put(R.drawable.snowman_pinchin0002, new Point(374, 193));
        offsets.put(R.drawable.elf_swipeup0014, new Point(468, 315));
        offsets.put(R.drawable.reindeer_swipeleft0020, new Point(384, 342));
        offsets.put(R.drawable.elf_pinchin_ball0003, new Point(460, 584));
        offsets.put(R.drawable.santa_swipeleft0001, new Point(415, 435));
        offsets.put(R.drawable.elf_pinchin_ball0021, new Point(500, 990));
        offsets.put(R.drawable.reindeer_swipeleft0014, new Point(317, 357));
        offsets.put(R.drawable.reindeer_tap0019, new Point(342, 337));
        offsets.put(R.drawable.reindeer_swipeleft0017, new Point(376, 371));
        offsets.put(R.drawable.reindeer_tap0018, new Point(342, 337));
        offsets.put(R.drawable.santa_tap0024, new Point(415, 435));
        offsets.put(R.drawable.snowman_pinchout0017, new Point(237, 580));
        offsets.put(R.drawable.santa_tap0010, new Point(270, 536));
        offsets.put(R.drawable.reindeer_swiperight0019, new Point(384, 389));
        offsets.put(R.drawable.elf_shake0019, new Point(231, 285));
        offsets.put(R.drawable.snowman_pinchin0016, new Point(167, 913));
        offsets.put(R.drawable.elf_swipeleft0001, new Point(435, 440));
        offsets.put(R.drawable.snowman_shake0022, new Point(64, 16));
        offsets.put(R.drawable.elf_pinchout0009, new Point(0, 0));
        offsets.put(R.drawable.santa_shake0012, new Point(355, 435));
        offsets.put(R.drawable.santa_pinchin0013, new Point(136, 219));
        offsets.put(R.drawable.elf_swipeleft0014, new Point(395, 460));
        offsets.put(R.drawable.santa_swipeup0002, new Point(418, 418));
        offsets.put(R.drawable.elf_swipedown0008, new Point(434, 515));
        offsets.put(R.drawable.elf_swipedown0007, new Point(435, 495));
        offsets.put(R.drawable.snowman_tap0001, new Point(429, 221));
        offsets.put(R.drawable.snowman_pinchout0007, new Point(325, 506));
        offsets.put(R.drawable.santa_idle0037, new Point(416, 430));
        offsets.put(R.drawable.santa_swipedown0012, new Point(265, 264));
        offsets.put(R.drawable.santa_idle0015, new Point(415, 431));
        offsets.put(R.drawable.santa_pinchout20019, new Point(0, 0));
        offsets.put(R.drawable.reindeer_swiperight0014, new Point(0, 335));
        offsets.put(R.drawable.reindeer_swipeleft0006, new Point(318, 177));
        offsets.put(R.drawable.santa_swipe_right20022, new Point(415, 435));
        offsets.put(R.drawable.santa_swipedown0020, new Point(0, 0));
        offsets.put(R.drawable.reindeer_tap0001, new Point(342, 337));
        offsets.put(R.drawable.elf_idle0013, new Point(435, 436));
        offsets.put(R.drawable.reindeer_swipeup0024, new Point(342, 337));
        offsets.put(R.drawable.santa_swipeup0013, new Point(312, 193));
        offsets.put(R.drawable.reindeer_pinchout0005, new Point(318, 308));
        offsets.put(R.drawable.santa_shake0008, new Point(255, 477));
        offsets.put(R.drawable.santa_pinchin0011, new Point(96, 154));
        offsets.put(R.drawable.reindeer_swipeleft0016, new Point(353, 389));
        offsets.put(R.drawable.snowman_swipeup0006, new Point(429, 33));
        offsets.put(R.drawable.snowman_shake0012, new Point(91, 0));
        offsets.put(R.drawable.elf_shake0017, new Point(201, 183));
        offsets.put(R.drawable.reindeer_swipedown0020, new Point(384, 510));
        offsets.put(R.drawable.santa_idle0042, new Point(415, 433));
        offsets.put(R.drawable.reindeer_pinchout0002, new Point(342, 337));
        offsets.put(R.drawable.santa_idle0044, new Point(415, 434));
        offsets.put(R.drawable.elf_swiperight0024, new Point(435, 440));
        offsets.put(R.drawable.santa_idle0006, new Point(415, 431));
        offsets.put(R.drawable.reindeer_pinchin0009, new Point(0, 0));
        offsets.put(R.drawable.santa_swipeleft0019, new Point(429, 428));
        offsets.put(R.drawable.reindeer_swipedown0011, new Point(384, 709));
        offsets.put(R.drawable.elf_shake0005, new Point(201, 183));
        offsets.put(R.drawable.snowman_swipeleft0010, new Point(429, 221));
        offsets.put(R.drawable.santa_idle0025, new Point(415, 434));
        offsets.put(R.drawable.reindeer_shake0006, new Point(384, 14));
        offsets.put(R.drawable.santa_tap0006, new Point(270, 557));
        offsets.put(R.drawable.santa_pinchout20008, new Point(0, 0));
        offsets.put(R.drawable.elf_pinchin_ball0002, new Point(447, 512));
        offsets.put(R.drawable.snowman_swipeup0009, new Point(429, 21));
        offsets.put(R.drawable.elf_swiperight0005, new Point(407, 458));
        offsets.put(R.drawable.santa_idle0039, new Point(415, 431));
        offsets.put(R.drawable.elf_swipeup0019, new Point(434, 440));
        offsets.put(R.drawable.elf_swipeleft0011, new Point(295, 460));
        offsets.put(R.drawable.reindeer_pinchout0008, new Point(246, 219));
        offsets.put(R.drawable.snowman_shake0023, new Point(382, 216));
        offsets.put(R.drawable.snowman_swiperight0021, new Point(429, 221));
        offsets.put(R.drawable.santa_pinchout20022, new Point(0, 0));
        offsets.put(R.drawable.elf_pinchin_ball0019, new Point(520, 618));
        offsets.put(R.drawable.snowman_shake0004, new Point(122, 0));
        offsets.put(R.drawable.elf_swipeup0024, new Point(435, 440));
        offsets.put(R.drawable.reindeer_pinchout0011, new Point(148, 99));
        offsets.put(R.drawable.santa_swipe_right20014, new Point(416, 340));
        offsets.put(R.drawable.elf_pinchin_ball0015, new Point(515, 95));
        offsets.put(R.drawable.santa_idle0002, new Point(415, 434));
        offsets.put(R.drawable.santa_pinchout20007, new Point(0, 0));
        offsets.put(R.drawable.santa_pinchin0014, new Point(170, 275));
        offsets.put(R.drawable.santa_swipedown0003, new Point(340, 460));
        offsets.put(R.drawable.snowman_pinchout0024, new Point(429, 221));
        offsets.put(R.drawable.santa_shake0009, new Point(243, 477));
        offsets.put(R.drawable.elf_tap0002, new Point(435, 440));
        offsets.put(R.drawable.santa_swipeleft0023, new Point(429, 429));
        offsets.put(R.drawable.elf_shake0015, new Point(263, 285));
        offsets.put(R.drawable.santa_swipe_right20008, new Point(336, 417));
        offsets.put(R.drawable.reindeer_tap0016, new Point(342, 337));
        offsets.put(R.drawable.elf_shake0020, new Point(324, 362));
        offsets.put(R.drawable.elf_shake0003, new Point(176, 324));
        offsets.put(R.drawable.reindeer_swipeup0011, new Point(210, 34));
        offsets.put(R.drawable.reindeer_tap0015, new Point(342, 337));
        offsets.put(R.drawable.santa_tap0016, new Point(270, 443));
        offsets.put(R.drawable.reindeer_pinchin0012, new Point(0, 0));
        offsets.put(R.drawable.elf_swipeleft0005, new Point(351, 460));
        offsets.put(R.drawable.elf_swipeup0022, new Point(435, 458));
        offsets.put(R.drawable.snowman_swipeleft0009, new Point(429, 221));
        offsets.put(R.drawable.santa_swipeup0014, new Point(311, 178));
        offsets.put(R.drawable.elf_pinchin_ball0026, new Point(467, 340));
        offsets.put(R.drawable.elf_swipedown0017, new Point(435, 470));
        offsets.put(R.drawable.santa_idle0012, new Point(416, 429));
        offsets.put(R.drawable.reindeer_swipedown0003, new Point(352, 366));
        offsets.put(R.drawable.santa_swipeleft0021, new Point(270, 462));
        offsets.put(R.drawable.santa_pinchin0024, new Point(415, 435));
        offsets.put(R.drawable.santa_pinchout20018, new Point(0, 0));
        offsets.put(R.drawable.reindeer_swipeup0022, new Point(221, 344));
        offsets.put(R.drawable.snowman_swiperight0019, new Point(429, 221));
        offsets.put(R.drawable.santa_idle0026, new Point(415, 433));
        offsets.put(R.drawable.reindeer_pinchout0013, new Point(106, 46));
        offsets.put(R.drawable.snowman_swipedown0003, new Point(359, 311));
        offsets.put(R.drawable.elf_swiperight0014, new Point(0, 768));
        offsets.put(R.drawable.snowman_tap0005, new Point(213, 221));
        offsets.put(R.drawable.snowman_swiperight0023, new Point(429, 221));
        offsets.put(R.drawable.reindeer_shake0007, new Point(383, 15));
        offsets.put(R.drawable.elf_swiperight0012, new Point(1280/2, 1280/2));
        offsets.put(R.drawable.snowman_pinchin0018, new Point(167, 370));
        offsets.put(R.drawable.santa_idle0045, new Point(415, 434));
        offsets.put(R.drawable.santa_swipeup0004, new Point(426, 385));
        offsets.put(R.drawable.santa_swipeleft0010, new Point(165, 589));
        offsets.put(R.drawable.elf_swipeleft0021, new Point(435, 375));
        offsets.put(R.drawable.reindeer_swiperight0013, new Point(0, 569));
        offsets.put(R.drawable.reindeer_swiperight0024, new Point(342, 337));
        offsets.put(R.drawable.reindeer_swipeleft0024, new Point(342, 337));
        offsets.put(R.drawable.elf_idle0004, new Point(435, 438));
        offsets.put(R.drawable.snowman_tap0014, new Point(83, 221));
        offsets.put(R.drawable.reindeer_pinchin0005, new Point(0, 0));
        offsets.put(R.drawable.santa_shake0011, new Point(326, 453));
        offsets.put(R.drawable.santa_swipedown0015, new Point(257, 0));
        offsets.put(R.drawable.reindeer_swipeup0012, new Point(210, 35));
        offsets.put(R.drawable.snowman_swipedown0004, new Point(320, 356));
        offsets.put(R.drawable.reindeer_tap0017, new Point(342, 337));
        offsets.put(R.drawable.reindeer_pinchin0002, new Point(0, 0));
        offsets.put(R.drawable.santa_idle0033, new Point(416, 429));
        offsets.put(R.drawable.elf_pinchout0002, new Point(376, 324));
        offsets.put(R.drawable.reindeer_pinchin0006, new Point(0, 0));
        offsets.put(R.drawable.elf_pinchin_ball0009, new Point(500, 990));
        offsets.put(R.drawable.santa_swipeup0015, new Point(267, 203));
        offsets.put(R.drawable.snowman_swipeleft0018, new Point(429, 221));
        offsets.put(R.drawable.reindeer_swipeup0005, new Point(344, 186));
        offsets.put(R.drawable.reindeer_swipeup0001, new Point(342, 337));
        offsets.put(R.drawable.santa_pinchin0012, new Point(111, 178));
        offsets.put(R.drawable.santa_pinchout20009, new Point(0, 0));
        offsets.put(R.drawable.santa_pinchout20016, new Point(0, 0));
        offsets.put(R.drawable.santa_tap0003, new Point(270, 435));
        offsets.put(R.drawable.elf_idle0020, new Point(435, 438));
        offsets.put(R.drawable.elf_swipeleft0018, new Point(435, 441));
        offsets.put(R.drawable.santa_swipedown0024, new Point(0, 435));
        offsets.put(R.drawable.snowman_shake0009, new Point(107, 0));
        offsets.put(R.drawable.santa_pinchout20017, new Point(0, 0));
        offsets.put(R.drawable.elf_idle0003, new Point(435, 439));
        offsets.put(R.drawable.snowman_shake0018, new Point(72, 0));
        offsets.put(R.drawable.elf_swipeup0008, new Point(378, 188));
        offsets.put(R.drawable.reindeer_pinchout0019, new Point(118, 62));
        offsets.put(R.drawable.snowman_swipeup0019, new Point(376, 133));
        offsets.put(R.drawable.elf_swiperight0004, new Point(395, 453));
        offsets.put(R.drawable.elf_shake0014, new Point(318, 362));
        offsets.put(R.drawable.elf_swiperight0015, new Point(0, 572));
        offsets.put(R.drawable.elf_pinchout0010, new Point(0, 0));
        offsets.put(R.drawable.snowman_swipedown0022, new Point(429, 221));
        offsets.put(R.drawable.reindeer_pinchin0017, new Point(0, 0));
        offsets.put(R.drawable.snowman_pinchout0008, new Point(307, 532));
        offsets.put(R.drawable.santa_swipeleft0011, new Point(415, 435));
        offsets.put(R.drawable.elf_swiperight0016, new Point(0, 623));
        offsets.put(R.drawable.reindeer_swiperight0002, new Point(342, 337));
        offsets.put(R.drawable.elf_pinchin_ball0004, new Point(472, 655));
        offsets.put(R.drawable.elf_swipeleft0016, new Point(444, 441));
        offsets.put(R.drawable.snowman_swiperight0002, new Point(139, 221));
        offsets.put(R.drawable.snowman_swiperight0004, new Point(224, 221));
        offsets.put(R.drawable.santa_pinchout20024, new Point(0, 0));
        offsets.put(R.drawable.santa_swipe_right20024, new Point(415, 435));
        offsets.put(R.drawable.santa_pinchin0023, new Point(358, 435));
        offsets.put(R.drawable.reindeer_pinchout0020, new Point(147, 97));
        offsets.put(R.drawable.santa_swipeup0008, new Point(429, 283));
        offsets.put(R.drawable.elf_pinchin_ball0030, new Point(435, 480));
        offsets.put(R.drawable.snowman_swipeup0015, new Point(253, 21));
        offsets.put(R.drawable.santa_swipedown0017, new Point(0, 0));
        offsets.put(R.drawable.elf_pinchin_ball0032, new Point(435, 445));
        offsets.put(R.drawable.snowman_swipedown0017, new Point(429, 129));
        offsets.put(R.drawable.santa_pinchout20005, new Point(0, 0));
        offsets.put(R.drawable.snowman_swipeleft0014, new Point(429, 221));
        offsets.put(R.drawable.reindeer_swiperight0011, new Point(26, 1021));
        offsets.put(R.drawable.reindeer_shake0009, new Point(384, 15));
        offsets.put(R.drawable.snowman_idle0012, new Point(429, 217));
        offsets.put(R.drawable.reindeer_swiperight0007, new Point(313, 629));
        offsets.put(R.drawable.snowman_idle0015, new Point(429, 217));
        offsets.put(R.drawable.santa_tap0004, new Point(270, 443));
        offsets.put(R.drawable.reindeer_pinchin0007, new Point(0, 0));
        offsets.put(R.drawable.santa_pinchin0021, new Point(270, 435));
        offsets.put(R.drawable.santa_swipe_right20012, new Point(426, 350));
        offsets.put(R.drawable.elf_swiperight0001, new Point(435, 440));
        offsets.put(R.drawable.snowman_pinchin0019, new Point(167, 234));
        offsets.put(R.drawable.reindeer_shake0017, new Point(384, 14));
        offsets.put(R.drawable.santa_swipe_right20006, new Point(346, 420));
        offsets.put(R.drawable.snowman_pinchout0023, new Point(382, 243));
        offsets.put(R.drawable.elf_shake0022, new Point(336, 324));
        offsets.put(R.drawable.santa_swipe_right20018, new Point(415, 389));
        offsets.put(R.drawable.snowman_swiperight0010, new Point(235, 221));
        offsets.put(R.drawable.santa_swipe_right20013, new Point(420, 336));
        offsets.put(R.drawable.snowman_swipeleft0015, new Point(429, 221));
        offsets.put(R.drawable.elf_idle0022, new Point(435, 439));
        offsets.put(R.drawable.santa_shake0007, new Point(257, 475));
        offsets.put(R.drawable.elf_swiperight0008, new Point(611, 565));
        offsets.put(R.drawable.santa_pinchin0020, new Point(235, 505));
        offsets.put(R.drawable.snowman_swipeleft0017, new Point(429, 221));
        offsets.put(R.drawable.elf_swipeleft0017, new Point(422, 440));
        offsets.put(R.drawable.santa_pinchin0003, new Point(268, 435));
        offsets.put(R.drawable.snowman_pinchout0004, new Point(377, 390));
        offsets.put(R.drawable.santa_tap0001, new Point(415, 435));
        offsets.put(R.drawable.santa_tap0018, new Point(270, 404));
        offsets.put(R.drawable.snowman_swipedown0019, new Point(429, 262));
        offsets.put(R.drawable.santa_idle0004, new Point(415, 432));
        offsets.put(R.drawable.reindeer_swipeup0004, new Point(342, 197));
        offsets.put(R.drawable.reindeer_swiperight0020, new Point(383, 352));
        offsets.put(R.drawable.santa_pinchin0022, new Point(270, 435));
        offsets.put(R.drawable.snowman_swipeup0018, new Point(214, 71));
        offsets.put(R.drawable.reindeer_swipeup0002, new Point(342, 321));
        offsets.put(R.drawable.elf_tap0022, new Point(435, 440));
        offsets.put(R.drawable.reindeer_swipeleft0009, new Point(284, 276));
        offsets.put(R.drawable.santa_idle0047, new Point(415, 435));
        offsets.put(R.drawable.snowman_swiperight0014, new Point(428, 221));
        offsets.put(R.drawable.reindeer_shake0012, new Point(384, 14));
        offsets.put(R.drawable.elf_pinchout0021, new Point(184, 0));
        offsets.put(R.drawable.snowman_pinchin0017, new Point(167, 596));
        offsets.put(R.drawable.santa_swipe_right20019, new Point(415, 435));
        offsets.put(R.drawable.reindeer_shake0011, new Point(383, 13));
        offsets.put(R.drawable.santa_tap0009, new Point(269, 567));
        offsets.put(R.drawable.elf_pinchin_ball0005, new Point(462, 727));
        offsets.put(R.drawable.snowman_pinchin0013, new Point(90, 1008));
        offsets.put(R.drawable.santa_swipeup0011, new Point(429, 221));
        offsets.put(R.drawable.reindeer_pinchin0010, new Point(0, 0));
        offsets.put(R.drawable.elf_swipedown0019, new Point(435, 474));
        offsets.put(R.drawable.snowman_tap0018, new Point(98, 221));
        offsets.put(R.drawable.elf_shake0007, new Point(244, 285));
        offsets.put(R.drawable.elf_idle0015, new Point(435, 436));
        offsets.put(R.drawable.santa_pinchin0008, new Point(111, 178));
        offsets.put(R.drawable.snowman_idle0008, new Point(429, 217));
        offsets.put(R.drawable.elf_swipedown0024, new Point(435, 440));
        offsets.put(R.drawable.reindeer_swipedown0022, new Point(354, 384));
        offsets.put(R.drawable.reindeer_tap0007, new Point(342, 337));
        offsets.put(R.drawable.elf_swipedown0013, new Point(397, 628));
        offsets.put(R.drawable.elf_pinchin_ball0028, new Point(434, 440));
        offsets.put(R.drawable.snowman_swipeleft0008, new Point(429, 221));
        offsets.put(R.drawable.snowman_tap0023, new Point(169, 221));
        offsets.put(R.drawable.reindeer_tap0012, new Point(342, 337));
        offsets.put(R.drawable.elf_tap0009, new Point(132, 248));
        offsets.put(R.drawable.elf_swipedown0004, new Point(435, 434));
        offsets.put(R.drawable.santa_shake0004, new Point(204, 478));
        offsets.put(R.drawable.reindeer_swipedown0002, new Point(344, 344));
        offsets.put(R.drawable.elf_pinchout0005, new Point(0, 0));
        offsets.put(R.drawable.snowman_swipeleft0002, new Point(429, 221));
        offsets.put(R.drawable.elf_swipedown0021, new Point(435, 467));
        offsets.put(R.drawable.reindeer_tap0021, new Point(342, 337));
        offsets.put(R.drawable.snowman_shake0011, new Point(95, 0));
        offsets.put(R.drawable.elf_pinchin_ball0017, new Point(520, 222));
        offsets.put(R.drawable.santa_shake0018, new Point(393, 420));
        offsets.put(R.drawable.reindeer_swiperight0004, new Point(348, 337));
        offsets.put(R.drawable.snowman_swipeleft0012, new Point(429, 221));
        offsets.put(R.drawable.reindeer_swipeup0009, new Point(210, 38));
        offsets.put(R.drawable.reindeer_shake0003, new Point(384, 193));
        offsets.put(R.drawable.elf_idle0016, new Point(435, 437));
        offsets.put(R.drawable.santa_swipeup0017, new Point(274, 245));
        offsets.put(R.drawable.santa_swipeup0009, new Point(429, 271));

    }

}
